import 'package:flutter/material.dart';

class MenuWidget extends StatelessWidget {
  final Function(String) onItemClick;
  final Function onProfilePictureClick;

  const MenuWidget({Key key, this.onItemClick, this.onProfilePictureClick})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
     return topToBottomMenu();
    return Container(
      decoration: BoxDecoration(
          gradient: LinearGradient(
              colors: [Color(0xfff46b45), Color(0xffeea849)],
              begin: Alignment.topLeft,
              end: Alignment.bottomRight)),
      padding: const EdgeInsets.only(top: 30),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          SizedBox(
            height: 30,
          ),
          GestureDetector(
            onTap: () {
              onProfilePictureClick();
            },
            child: Center(
              child: Card(
                child: CircleAvatar(
                  radius: 61,
                  backgroundColor: Colors.white70,
                  child: CircleAvatar(
                    radius: 60,
                    backgroundImage:
                        AssetImage('assets/images/profile_pic.jpg'),
                  ),
                ),
                elevation: 30.0,
                shape: CircleBorder(),
                clipBehavior: Clip.antiAlias,
              ),
            ),
          ),
          SizedBox(
            height: 20,
          ),
          Text(
            'Nick',
            style: TextStyle(
                color: Colors.white,
                fontWeight: FontWeight.bold,
                fontSize: 30,
                fontFamily: 'BalsamiqSans'),
          ),
          SizedBox(
            height: 20,
          ),
          sliderItem('Home', Icons.home),
          sliderItem('Add Post', Icons.add_circle),
          sliderItem('Notification', Icons.notifications_active),
          sliderItem('Likes', Icons.favorite),
          sliderItem('Setting', Icons.settings),
          sliderItem('LogOut', Icons.arrow_back_ios)
        ],
      ),
    );
  }

  topToBottomMenu() => Container(
        //height: 160,
        decoration: BoxDecoration(
            gradient: LinearGradient(
                colors: [Color(0xfff46b45), Color(0xffeea849)],
                begin: Alignment.topLeft,
                end: Alignment.bottomRight)),
        padding: const EdgeInsets.only(top: 30, left: 15, right: 10, bottom: 20),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                SizedBox(
                  height: 15,
                ),
                GestureDetector(
                  onTap: () {
                    onProfilePictureClick();
                  },
                  child: Center(
                    child: Card(
                      child: CircleAvatar(
                        radius: 26,
                        backgroundColor: Colors.white70,
                        child: CircleAvatar(
                          radius: 25,
                          backgroundImage:
                          AssetImage('assets/images/profile_pic.jpg'),
                        ),
                      ),
                      elevation: 30.0,
                      shape: CircleBorder(),
                      clipBehavior: Clip.antiAlias,
                    ),
                  ),
                ),
                SizedBox(
                  height: 5,
                ),
                Text(
                  'Nick',
                  style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.bold,
                      fontSize: 24,
                      fontFamily: 'BalsamiqSans'),
                ),
                SizedBox(
                  height: 6,
                ),
              ],
            ),
            SizedBox(
              width: 15,
            ),
            Expanded(
              child: Column(
                children: <Widget>[
                  sliderItem('Home', Icons.home),
                  sliderItem('Post', Icons.add_circle),
                  sliderItem('Notification', Icons.notifications_active),
                ],
              ),
            ),
            Expanded(
              child: Column(
                children: <Widget>[
                  sliderItem('Likes', Icons.favorite),
                  sliderItem('Setting', Icons.settings),
                  sliderItem('LogOut', Icons.arrow_back_ios)
                ],
              ),
            )
          ],
        ),
      );

  Widget sliderItem(String title, IconData icons) => ListTile(
      title: Text(
        title,
        style: TextStyle(
            color: Colors.white70, fontFamily: 'BalsamiqSans_Regular'),
      ),
      leading: Icon(
        icons,
        color: Colors.white60,
      ),
      onTap: () {
        onItemClick(title);
      });
}
